import { DayCellProps, DayCellsProps, ToolBarProps, AvailSlotsProps, ToolBarButtonProps, AvailSlotProps } from '../types';
declare type StyleOrFunc<StyleProps> = CSSProperties | ((p?: StyleProps) => CSSProperties);
export interface OverridableComponentProps<ComponentProps, InternalProps, StyleProps> {
    style?: StyleOrFunc<StyleProps>;
    className?: string;
    Root?: React.ElementType<ComponentProps>;
    internalProps?: InternalProps;
}
export interface ResolvedOverride<ComponentProps, InternalProps> {
    style?: CSSProperties;
    className?: string;
    Root?: React.ElementType<ComponentProps>;
    internalProps?: InternalProps;
}
import { CSSProperties } from 'react';
declare const DefaultToolBar: OverridableComponentProps<ToolBarProps, {}, {}>;
declare const DefaultToolBarButton: OverridableComponentProps<ToolBarButtonProps, {}, {}>;
declare const DefaultWeekdays: OverridableComponentProps<{}, {}, {}>;
declare const DefaultDayCells: OverridableComponentProps<DayCellsProps, {}, {}>;
declare const DefaultDayCell: OverridableComponentProps<DayCellProps, {}, {
    isSelected: boolean;
    isToday: boolean;
    hasAvail: boolean;
}>;
declare const DefaultAvailabiliies: OverridableComponentProps<AvailSlotsProps, {}, {}>;
declare const DefaultAvailSlot: OverridableComponentProps<AvailSlotProps, {}, {}>;
declare type ExtractStyleProps<Overridable> = Overridable extends OverridableComponentProps<infer _T, infer _U, infer Z> ? Z : never;
export declare const defaultComponents: {
    ToolBar: OverridableComponentProps<ToolBarProps, {}, {}>;
    ToolBarButton: OverridableComponentProps<ToolBarButtonProps, {}, {}>;
    Weekdays: OverridableComponentProps<{}, {}, {}>;
    DayCells: OverridableComponentProps<DayCellsProps, {}, {}>;
    DayCell: OverridableComponentProps<DayCellProps, {}, {
        isSelected: boolean;
        isToday: boolean;
        hasAvail: boolean;
    }>;
    Availabilities: OverridableComponentProps<AvailSlotsProps, {}, {}>;
    AvailSlot: OverridableComponentProps<AvailSlotProps, {}, {}>;
};
export declare type Overrides = typeof defaultComponents;
export declare function getOverride<O extends OverridableComponentProps<T, U, K>, T, U, K>(o: O | undefined, defaultSpec: O, styleProps?: K, _t?: T, _u?: U, _k?: K): ResolvedOverride<T, U>;
export declare function getToolBarOverride(overrides: Overrides | undefined, defaultSpec: typeof DefaultToolBar): ResolvedOverride<ToolBarProps, {}>;
export declare function getToolBarButtonOverride(overrides: Overrides | undefined, defaultSpec: typeof DefaultToolBarButton): ResolvedOverride<ToolBarButtonProps, {}>;
export declare function getWeekdaysOVerride(overrides: Overrides | undefined, defaultSpec: typeof DefaultWeekdays): ResolvedOverride<{}, {}>;
export declare function getDayCellsOverride(overrides: Overrides | undefined, defaultSpec: typeof DefaultDayCells): ResolvedOverride<DayCellsProps, {}>;
export declare function getDayCellOverride(overrides: Overrides | undefined, defaultSpec: typeof DefaultDayCell, styleProps?: ExtractStyleProps<typeof DefaultDayCell>): ResolvedOverride<DayCellProps, {}>;
export declare function getAvailsOverride(overrides: Overrides | undefined, defaultSpec: typeof DefaultAvailabiliies): ResolvedOverride<AvailSlotsProps, {}>;
export declare function getAvailOverride(overrides: Overrides | undefined, defaultSpec: typeof DefaultAvailSlot): ResolvedOverride<AvailSlotProps, {}>;
export {};
